
#ifndef KCDDB_EXPORT_H
#define KCDDB_EXPORT_H

#ifdef KCDDB_STATIC_DEFINE
#  define KCDDB_EXPORT
#  define KCDDB_NO_EXPORT
#else
#  ifndef KCDDB_EXPORT
#    ifdef KF5Cddb_EXPORTS
        /* We are building this library */
#      define KCDDB_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KCDDB_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KCDDB_NO_EXPORT
#    define KCDDB_NO_EXPORT 
#  endif
#endif

#ifndef KCDDB_DEPRECATED
#  define KCDDB_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KCDDB_DEPRECATED_EXPORT
#  define KCDDB_DEPRECATED_EXPORT KCDDB_EXPORT KCDDB_DEPRECATED
#endif

#ifndef KCDDB_DEPRECATED_NO_EXPORT
#  define KCDDB_DEPRECATED_NO_EXPORT KCDDB_NO_EXPORT KCDDB_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KCDDB_NO_DEPRECATED
#    define KCDDB_NO_DEPRECATED
#  endif
#endif

#endif
