
#ifndef KCDDBWIDGETS_EXPORT_H
#define KCDDBWIDGETS_EXPORT_H

#ifdef KCDDBWIDGETS_STATIC_DEFINE
#  define KCDDBWIDGETS_EXPORT
#  define KCDDBWIDGETS_NO_EXPORT
#else
#  ifndef KCDDBWIDGETS_EXPORT
#    ifdef KF5CddbWidgets_EXPORTS
        /* We are building this library */
#      define KCDDBWIDGETS_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KCDDBWIDGETS_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KCDDBWIDGETS_NO_EXPORT
#    define KCDDBWIDGETS_NO_EXPORT 
#  endif
#endif

#ifndef KCDDBWIDGETS_DEPRECATED
#  define KCDDBWIDGETS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KCDDBWIDGETS_DEPRECATED_EXPORT
#  define KCDDBWIDGETS_DEPRECATED_EXPORT KCDDBWIDGETS_EXPORT KCDDBWIDGETS_DEPRECATED
#endif

#ifndef KCDDBWIDGETS_DEPRECATED_NO_EXPORT
#  define KCDDBWIDGETS_DEPRECATED_NO_EXPORT KCDDBWIDGETS_NO_EXPORT KCDDBWIDGETS_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KCDDBWIDGETS_NO_DEPRECATED
#    define KCDDBWIDGETS_NO_DEPRECATED
#  endif
#endif

#endif
